---
title: <span class="badge object-type-scalar"></span> Mile
---
# <span class="badge object-type-scalar"></span> Mile

Length: mile (mi)

## Definition

```python
# Length: mile (mi)
Mile: typing.Literal["lengthmi"] = "lengthmi"
```
